jactorch.utils.meta
===================

.. automodule:: jactorch.utils.meta

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      as_cpu
      as_cuda
      as_detached
      as_float
      as_numpy
      as_tensor
      as_variable
      mark_volatile
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: as_cpu

.. autofunction:: as_cuda

.. autofunction:: as_detached

.. autofunction:: as_float

.. autofunction:: as_numpy

.. autofunction:: as_tensor

.. autofunction:: as_variable

.. autofunction:: mark_volatile


